@@ -1,14 +1,12 @@
 ##----------------------------------------------------------------------------
 ## WebSocket Client & Server - ~/lib/WebSocket/Connection.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/09/13
-## Modified 2021/09/13
-## All rights reserved
-## 
-## This program is free software; you can redistribute  it  and/or  modify  it
-## under the same terms as Perl itself.
+## Modified 2021/10/23
+## You can use, copy, modify and  redistribute  this  package  and  associated
+## files under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 package WebSocket::Connection;
 BEGIN
@@ -20,13 +18,14 @@ BEGIN
     use parent qw( WebSocket );
     use Encode;
     use HTTP::Response ();
+    use HTTP::Status ();
     use JSON ();
     use Nice::Try;
     use Socket qw( IPPROTO_TCP TCP_NODELAY );
     use URI;
     use WebSocket::Handshake::Server;
     use WebSocket::Frame;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 sub init
@@ -651,6 +650,8 @@ sub shutdown
 
 sub socket { return( shift->_set_get_object_without_init( 'socket', 'IO::Socket', @_ ) ); }
 
+sub status_message { return( HTTP::Status::status_message( $_[1] ) ); }
+
 sub subprotocol
 {
     my $self = shift( @_ );
@@ -708,7 +709,7 @@ WebSocket::Connection - WebSocket Server Connection
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
@@ -889,6 +890,10 @@ Provided with some text message, and this will utf8 encode it using L<Encode/enc
 
 Set or get the L<WebSocket::Server> object.
 
+=head2 status_message
+
+Returns the status message provided by the other party.
+
 =head2 shutdown
 
 Terminate the client connection by calling L<WebSocket::Server/disconnect> passing it the current connection socket. This does not terminate the server connection itself. For this, check L<WebSocket::Server/shutdown>.
@@ -924,4 +929,3 @@ Copyright(c) 2021 DEGUEST Pte. Ltd. DEGUEST Pte. Ltd.
 You can use, copy, modify and redistribute this package and associated files under the same terms as Perl itself.
 
 =cut
-
